@@ -15,7 +15,7 @@ class NotificationStack(Stack):
         pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name)
 
         cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
-            application_id=pinpoint_app.logical_id,
+            application_id=pinpoint_app.ref,
 
             # the properties below are optional
             bundle_id="bundleId",
